You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tinkerpop.apache.org by sp...@apache.org on 2015/04/17 14:54:12 UTC

[1/6] incubator-tinkerpop git commit: Clean up javadoc warnings in gremlin-core.

Repository: incubator-tinkerpop
Updated Branches:
  refs/heads/refactor-io 4a7a2a521 -> 42f367a36


Clean up javadoc warnings in gremlin-core.

Left warnings on DefaultIo since that will likely be removed when refactor-io branch is merged back to master.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/ddc29f11
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/ddc29f11
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/ddc29f11

Branch: refs/heads/refactor-io
Commit: ddc29f11430830779cbba7c62d2ef8453a17bd5d
Parents: 7bd47a8
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Fri Apr 17 06:41:32 2015 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Fri Apr 17 06:41:32 2015 -0400

----------------------------------------------------------------------
 .../gremlin/process/traversal/Path.java         |  9 +++------
 .../process/traversal/TraversalStrategies.java  |  4 ----
 .../gremlin/process/traversal/Traverser.java    | 12 ++++++-----
 .../gremlin/process/traversal/util/Metrics.java | 10 ----------
 .../structure/util/batch/BatchGraph.java        | 21 ++++++++------------
 5 files changed, 18 insertions(+), 38 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/ddc29f11/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Path.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Path.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Path.java
index 3d54cd2..b83bd23 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Path.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Path.java
@@ -18,6 +18,7 @@
  */
 package org.apache.tinkerpop.gremlin.process.traversal;
 
+import org.apache.tinkerpop.gremlin.structure.Graph;
 import org.javatuples.Pair;
 
 import java.util.ArrayList;
@@ -29,10 +30,9 @@ import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
 /**
- * A Path denotes a particular walk through a {@link org.apache.tinkerpop.gremlin.structure.Graph} as defined by a {@link Traverser}.
+ * A Path denotes a particular walk through a {@link Graph} as defined by a {@link Traverser}.
  * In abstraction, any Path implementation maintains two lists: a list of sets of labels and a list of objects.
- * The list of labels are the labels of the steps traversed.
- * The list of objects are the objects traversed.
+ * The list of labels are the labels of the steps traversed. The list of objects are the objects traversed.
  *
  * @author Marko A. Rodriguez (http://markorodriguez.com)
  */
@@ -130,9 +130,6 @@ public interface Path extends Cloneable {
      */
     public List<Set<String>> labels();
 
-    /**
-     * {@inheritDoc}
-     */
     @SuppressWarnings("CloneDoesntDeclareCloneNotSupportedException")
     public Path clone();
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/ddc29f11/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/TraversalStrategies.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/TraversalStrategies.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/TraversalStrategies.java
index 92bc7b5..077cc9c 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/TraversalStrategies.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/TraversalStrategies.java
@@ -61,7 +61,6 @@ public interface TraversalStrategies extends Serializable, Cloneable {
      * This method must ensure that the strategies are sorted prior to application.
      *
      * @param traversal the traversal to apply the strategies to
-     * @param engine    the engine that the traversal is going to be executed on
      */
     public void applyStrategies(final Traversal.Admin<?, ?> traversal);
 
@@ -84,9 +83,6 @@ public interface TraversalStrategies extends Serializable, Cloneable {
     @SuppressWarnings("unchecked")
     public TraversalStrategies removeStrategies(final Class<? extends TraversalStrategy>... strategyClasses);
 
-    /**
-     * {@inheritDoc}
-     */
     @SuppressWarnings("CloneDoesntDeclareCloneNotSupportedException")
     public TraversalStrategies clone();
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/ddc29f11/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Traverser.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Traverser.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Traverser.java
index 97eef72..d177842 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Traverser.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/Traverser.java
@@ -25,9 +25,10 @@ import org.apache.tinkerpop.gremlin.structure.util.Attachable;
 import java.io.Serializable;
 
 /**
- * A {@link Traverser} represents the current state of an object flowing through a {@link Traversal}.
- * A traverser maintains a reference to the current object, a traverser-local "sack", a traversal-global sideEffect, a bulk count, and a path history.
- * <p/>
+ * A {@code Traverser} represents the current state of an object flowing through a {@link Traversal}.
+ * A traverser maintains a reference to the current object, a traverser-local "sack", a traversal-global sideEffect,
+ * a bulk count, and a path history.
+ * <br/>
  * Different types of traverser can exist depending on the semantics of the traversal and the desire for
  * space/time optimizations of the developer.
  *
@@ -149,7 +150,7 @@ public interface Traverser<T> extends Serializable, Comparable<Traverser<T>>, Cl
         public static final String HALT = "halt";
 
         /**
-         * When two traversers are {@link Traverser#equals} to each other, then they can be merged.
+         * When two traversers are have equality with each other, then they can be merged.
          * This method is used to merge the traversers into a single traverser.
          * This is used for optimization where instead of enumerating all traversers, they can be counted.
          *
@@ -219,7 +220,8 @@ public interface Traverser<T> extends Serializable, Comparable<Traverser<T>>, Cl
 
         /**
          * If the traverser has "no future" then it is done with its lifecycle.
-         * This does not mean that the traverser is "dead," only that it has successfully passed through a {@link Traversal}.
+         * This does not mean that the traverser is "dead," only that it has successfully passed through a
+         * {@link Traversal}.
          *
          * @return Whether the traverser is done executing or not
          */

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/ddc29f11/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/util/Metrics.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/util/Metrics.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/util/Metrics.java
index 6f2c963..4492ee7 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/util/Metrics.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/process/traversal/util/Metrics.java
@@ -31,14 +31,8 @@ import java.util.concurrent.TimeUnit;
  */
 public interface Metrics {
 
-
-
-
     /**
      * Get the duration of execution time taken.
-     *
-     * @param units
-     * @return
      */
     public long getDuration(TimeUnit units);
 
@@ -46,7 +40,6 @@ public interface Metrics {
      * Get the count for the corresponding countKey.
      *
      * @param countKey key for counter to get.
-     * @return
      */
     public long getCount(String countKey);
 
@@ -71,7 +64,6 @@ public interface Metrics {
      */
     public String getId();
 
-
     /**
      * Get the nested Metrics objects. Metrics will be ordered in the order they were inserted.
      *
@@ -82,7 +74,6 @@ public interface Metrics {
     /**
      * Get a nested Metrics object by Id.
      *
-     * @param metricsId
      * @return a nested Metrics object.
      */
     Metrics getNested(String metricsId);
@@ -98,7 +89,6 @@ public interface Metrics {
      * Obtain the annotation with the specified key. Values may be of type String or Number.
      *
      * @param key key of the annotation to obtain.
-     * @return
      */
     public Object getAnnotation(String key);
 }

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/ddc29f11/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
index e156815..a2a26f9 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/util/batch/BatchGraph.java
@@ -23,6 +23,7 @@ import org.apache.commons.configuration.Configuration;
 import org.apache.tinkerpop.gremlin.process.computer.GraphComputer;
 import org.apache.tinkerpop.gremlin.process.traversal.T;
 import org.apache.tinkerpop.gremlin.process.traversal.Traversal;
+import org.apache.tinkerpop.gremlin.process.traversal.strategy.decoration.ElementIdStrategy;
 import org.apache.tinkerpop.gremlin.structure.Direction;
 import org.apache.tinkerpop.gremlin.structure.Edge;
 import org.apache.tinkerpop.gremlin.structure.Element;
@@ -45,9 +46,9 @@ import java.util.function.Consumer;
 import java.util.function.Function;
 
 /**
- * {@code BatchGraph} is a wrapper that enables batch loading of a large number of edges and vertices by chunking the entire
- * load into smaller batches and maintaining a sideEffects-efficient vertex cache so that the entire transactional state can
- * be flushed after each chunk is loaded.
+ * {@code BatchGraph} is a wrapper that enables batch loading of a large number of edges and vertices by chunking the
+ * entire load into smaller batches and maintaining a sideEffects-efficient vertex cache so that the entire
+ * transactional state can be flushed after each chunk is loaded.
  * <br />
  * {@code BatchGraph} is ONLY meant for loading data and does not support any retrieval or removal operations.
  * That is, BatchGraph only supports the following methods:
@@ -55,20 +56,14 @@ import java.util.function.Function;
  * - {@link Vertex#addEdge(String, org.apache.tinkerpop.gremlin.structure.Vertex, Object...)} for adding edges
  * - Property getter, setter and removal methods for vertices and edges.
  * <br />
- * An important limitation of BatchGraph is that edge properties can only be set immediately after the edge has been added.
- * If other vertices or edges have been created in the meantime, setting, getting or removing properties will throw
- * exceptions. This is done to avoid caching of edges which would require a great amount of sideEffects.
+ * An important limitation of BatchGraph is that edge properties can only be set immediately after the edge has been
+ * added. If other vertices or edges have been created in the meantime, setting, getting or removing properties will
+ * throw exceptions. This is done to avoid caching of edges which would require a great amount of sideEffects.
  * <br />
  * {@code BatchGraph} can also automatically set the provided element ids as properties on the respective element. Use
  * {@link Builder#vertexIdKey(String)} and {@link Builder#edgeIdKey(String)} to set the keys
  * for the vertex and edge properties respectively. This allows to make the loaded baseGraph compatible for later
- * operation with {@link org.apache.tinkerpop.gremlin.structure.strategy.IdStrategy}.
- * <br/>
- * Note that {@code BatchGraph} itself is not a {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy} because
- * it requires that the {@link Vertex} implementation not hold on to the underlying {@link Vertex} reference and
- * {@link org.apache.tinkerpop.gremlin.structure.strategy.StrategyVertex} does that by it's very nature.  While it might
- * be possible to work around this issue, it is likely better for performance to simply leave this as a "half-wrapper"
- * implementation, instead of forcing it into a {@link org.apache.tinkerpop.gremlin.structure.strategy.GraphStrategy}.
+ * operation with {@link ElementIdStrategy}.
  *
  * @author Matthias Broecheler (http://www.matthiasb.com)
  * @author Stephen Mallette (http://stephen.genoprime.com)


[4/6] incubator-tinkerpop git commit: Fix javadoc warnings in tinkergraph.

Posted by sp...@apache.org.
Fix javadoc warnings in tinkergraph.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/c6c8985c
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/c6c8985c
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/c6c8985c

Branch: refs/heads/refactor-io
Commit: c6c8985c06324c726dfbf431fdddb8e50ac4f0da
Parents: 287553e
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Fri Apr 17 07:35:56 2015 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Fri Apr 17 07:35:56 2015 -0400

----------------------------------------------------------------------
 .../tinkergraph/structure/TinkerGraph.java      | 36 ++++++++++----------
 1 file changed, 18 insertions(+), 18 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/c6c8985c/tinkergraph-gremlin/src/main/java/org/apache/tinkerpop/gremlin/tinkergraph/structure/TinkerGraph.java
----------------------------------------------------------------------
diff --git a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
index 469a10a..a578908 100644
--- a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
+++ b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
@@ -72,8 +72,9 @@ public abstract class AbstractGremlinSuite extends Suite {
      * Indicates that this suite is for testing a gremlin flavor and is therefore not responsible for validating
      * the suite against what the {@link Graph} implementation opts-in for. This setting will let Gremlin flavor
      * developers run their test cases against a {@link Graph} without the need for the {@link Graph} to supply
-     * an {@link Graph.OptIn} annotation.  Not having that annotation is a likely case for flavors while they are
-     * under development and a {@link Graph.OptIn} is not possible.
+     * an {@link org.apache.tinkerpop.gremlin.structure.Graph.OptIn} annotation.  Not having that annotation is a
+     * likely case for flavors while they are under development and a
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph.OptIn} is not possible.
      */
     private final boolean gremlinFlavorSuite;
 
@@ -84,10 +85,12 @@ public abstract class AbstractGremlinSuite extends Suite {
      * @param builder Required for JUnit Suite construction
      * @param testsToExecute The list of tests to execute
      * @param testsToEnforce The list of tests to "enforce" such that a check is made to ensure that in this list,
-     *                       there exists an implementation in the testsToExecute (use {@code null} for no enforcement.
-     * @param gremlinFlavorSuite Ignore validation of {@link Graph.OptIn} annotations which is typically reserved for
-     *                           structure tests
-     * @param traversalEngineType The {@link TraversalEngine.Type} to enforce on this suite
+     *                       there exists an implementation in the testsToExecute (use {@code null} for no
+     *                       enforcement).
+     * @param gremlinFlavorSuite Ignore validation of {@link org.apache.tinkerpop.gremlin.structure.Graph.OptIn}
+     *                           annotations which is typically reserved for structure tests
+     * @param traversalEngineType The {@link org.apache.tinkerpop.gremlin.process.traversal.TraversalEngine.Type} to
+     *                            enforce on this suite
      */
     public AbstractGremlinSuite(final Class<?> klass, final RunnerBuilder builder, final Class<?>[] testsToExecute,
                                 final Class<?>[] testsToEnforce, final boolean gremlinFlavorSuite,
@@ -162,7 +165,7 @@ public abstract class AbstractGremlinSuite extends Suite {
     /**
      * Filter a list of test classes through the GREMLIN_TESTS environment variable list.
      */
-    private static Class<?>[] filterSpecifiedTests(Class<?>[] allTests) {
+    private static Class<?>[] filterSpecifiedTests(final Class<?>[] allTests) {
         if (null == allTests) return allTests;
 
         Class<?>[] filteredTests;
@@ -225,7 +228,7 @@ public abstract class AbstractGremlinSuite extends Suite {
     }
 
     /**
-     * Filter for tests in the suite which is controlled by the {@link Graph.OptOut} annotation.
+     * Filter for tests in the suite which is controlled by the {@link org.apache.tinkerpop.gremlin.structure.Graph.OptOut} annotation.
      */
     public static class OptOutTestFilter extends Filter {
 

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/287553ec/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/GraphProvider.java
----------------------------------------------------------------------
diff --git a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/GraphProvider.java b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/GraphProvider.java
index fbc2cd2..9e15f70 100644
--- a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/GraphProvider.java
+++ b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/GraphProvider.java
@@ -78,20 +78,20 @@ public interface GraphProvider {
     }};
 
     /**
-     * Create a {@link org.apache.tinkerpop.gremlin.process.traversal.dsl.graph.GraphTraversalSource} from a {@link Graph} instance.  The default implementation uses the
-     * {@link org.apache.tinkerpop.gremlin.process.traversal.engine.StandardTraversalEngine} so vendors should
-     * override as necessary if their implementation is testing something that requires a different engine type,
-     * like those tests for {@link org.apache.tinkerpop.gremlin.process.traversal.TraversalEngine.Type}.
+     * Create a {@link GraphTraversalSource} from a {@link Graph} instance.  The default implementation uses the
+     * {@link StandardTraversalEngine} so vendors should override as necessary if their implementation is testing
+     * something that requires a different engine type, like those tests for
+     * {@link org.apache.tinkerpop.gremlin.process.traversal.TraversalEngine.Type}.
      */
     public default GraphTraversalSource traversal(final Graph graph) {
         return GraphTraversalSource.standard().create(graph);
     }
 
     /**
-     * Create a {@link org.apache.tinkerpop.gremlin.process.traversal.dsl.graph.GraphTraversalSource} from a {@link Graph} instance.  The default implementation uses the
-     * {@link org.apache.tinkerpop.gremlin.process.traversal.engine.StandardTraversalEngine} so vendors should
-     * override as necessary if their implementation is testing something that requires a different engine type,
-     * like those tests for {@link org.apache.tinkerpop.gremlin.process.traversal.TraversalEngine.Type}.
+     * Create a {@link GraphTraversalSource} from a {@link Graph} instance.  The default implementation uses the
+     * {@link StandardTraversalEngine} so vendors should override as necessary if their implementation is testing
+     * something that requires a different engine type, like those tests for
+     * {@link org.apache.tinkerpop.gremlin.process.traversal.TraversalEngine.Type}.
      * <br/>
      * Implementations should apply strategies as necessary to the
      * {@link org.apache.tinkerpop.gremlin.process.traversal.dsl.graph.GraphTraversalSource.Builder} before calling
@@ -105,17 +105,17 @@ public interface GraphProvider {
 
     /**
      * Creates a new {@link org.apache.tinkerpop.gremlin.structure.Graph} instance using the default
-     * {@link org.apache.commons.configuration.Configuration} from {@link #standardGraphConfiguration(Class, String, LoadGraphWith.GraphData)}.
-     * The default implementation converts the passes the
+     * {@code org.apache.commons.configuration.Configuration} from
+     * {@link #standardGraphConfiguration(Class, String, LoadGraphWith.GraphData)}.
      */
     default public Graph standardTestGraph(final Class<?> test, final String testMethodName, final LoadGraphWith.GraphData loadGraphWith) {
         return GraphFactory.open(standardGraphConfiguration(test, testMethodName, loadGraphWith));
     }
 
     /**
-     * Creates a new {@link org.apache.tinkerpop.gremlin.structure.Graph} instance from the Configuration object using
-     * {@link org.apache.tinkerpop.gremlin.structure.util.GraphFactory}. The assumption here is that the {@code Configuration}
-     * has been created by one of the {@link #newGraphConfiguration(String, Class, String, LoadGraphWith.GraphData)} methods and has therefore
+     * Creates a new {@link Graph} instance from the Configuration object using {@link GraphFactory}. The assumption
+     * here is that the {@code Configuration} has been created by one of the
+     * {@link #newGraphConfiguration(String, Class, String, LoadGraphWith.GraphData)} methods and has therefore
      * already been modified by the implementation as necessary for {@link Graph} creation.
      */
     default public Graph openTestGraph(final Configuration config) {
@@ -123,10 +123,10 @@ public interface GraphProvider {
     }
 
     /**
-     * Gets the {@link org.apache.commons.configuration.Configuration} object that can construct a {@link org.apache.tinkerpop.gremlin.structure.Graph} instance from {@link org.apache.tinkerpop.gremlin.structure.util.GraphFactory}.
-     * Note that this method should create a {@link org.apache.tinkerpop.gremlin.structure.Graph} using the {@code graphName} of "standard", meaning it
-     * should always return a configuration instance that generates the same {@link org.apache.tinkerpop.gremlin.structure.Graph} from the
-     * {@link org.apache.tinkerpop.gremlin.structure.util.GraphFactory}.
+     * Gets the {@code Configuration} object that can construct a {@link Graph} instance from {@link GraphFactory}.
+     * Note that this method should create a {@link Graph} using the {@code graphName} of "standard", meaning it
+     * should always return a configuration instance that generates the same {@link Graph} from the
+     * {@link GraphFactory}.
      */
     default public Configuration standardGraphConfiguration(final Class<?> test, final String testMethodName, final LoadGraphWith.GraphData loadGraphWith) {
         return newGraphConfiguration("standard", test, testMethodName, Collections.<String, Object>emptyMap(), loadGraphWith);
@@ -135,7 +135,7 @@ public interface GraphProvider {
     /**
      * If possible (usually with persisted graph) clear the space on disk given the configuration that would be used
      * to construct the graph.  The default implementation simply calls
-     * {@link #clear(org.apache.tinkerpop.gremlin.structure.Graph, org.apache.commons.configuration.Configuration)} with
+     * {@link #clear(Graph, org.apache.commons.configuration.Configuration)} with
      * a null graph argument.
      */
     public default void clear(final Configuration configuration) throws Exception {
@@ -143,9 +143,9 @@ public interface GraphProvider {
     }
 
     /**
-     * Clears a {@link org.apache.tinkerpop.gremlin.structure.Graph} of all data and settings.  Implementations will have
-     * different ways of handling this. For a brute force approach, implementers can simply delete data directories
-     * provided in the configuration. Implementers may choose a more elegant approach if it exists.
+     * Clears a {@link Graph} of all data and settings.  Implementations will have different ways of handling this.
+     * For a brute force approach, implementers can simply delete data directories provided in the configuration.
+     * Implementers may choose a more elegant approach if it exists.
      * <br/>
      * Implementations should be able to accept an argument of null for the Graph, in which case the only action
      * that can be performed is a clear given the configuration.  The method will typically be called this way
@@ -174,7 +174,7 @@ public interface GraphProvider {
     /**
      * When implementing this method ensure that a test suite can override any settings EXCEPT the
      * "gremlin.graph" setting which should be defined by the implementer. It should provide a
-     * {@link org.apache.commons.configuration.Configuration} that will generate a graph unique to that {@code graphName}.
+     * {@code Configuration} that will generate a graph unique to that {@code graphName}.
      *
      * @param graphName              a unique test graph name
      * @param test                   the test class
@@ -191,7 +191,7 @@ public interface GraphProvider {
     /**
      * When implementing this method ensure that a test suite can override any settings EXCEPT the
      * "gremlin.graph" setting which should be defined by the implementer. It should provide a
-     * {@link org.apache.commons.configuration.Configuration} that will generate a graph unique to that {@code graphName}.
+     * {@code Configuration} that will generate a graph unique to that {@code graphName}.
      *
      * @param graphName      a unique test graph name
      * @param test           the test class
@@ -206,11 +206,11 @@ public interface GraphProvider {
     }
 
     /**
-     * Tests are annotated with a {@link org.apache.tinkerpop.gremlin.LoadGraphWith} annotation. These annotations tell
-     * the test what kind of data to preload into the graph instance.  It is up to the implementation to load the
-     * graph with the data specified by that annotation. This method also represents the place where indices should
-     * be configured according the the {@link Graph} implementation's API. Implementers can use the {@code testClass}
-     * and {@code testName} arguments to implement test specific configurations to their graphs.
+     * Tests are annotated with a {@link LoadGraphWith} annotation. These annotations tell the test what kind of data
+     * to preload into the graph instance.  It is up to the implementation to load the graph with the data specified
+     * by that annotation. This method also represents the place where indices should be configured according the
+     * the {@link Graph} implementation's API. Implementers can use the {@code testClass} and {@code testName}
+     * arguments to implement test specific configurations to their graphs.
      *
      * @param graph         the {@link Graph} instance to load data into constructed by this {@code GraphProvider}
      * @param loadGraphWith the annotation for the currently running test - this value may be null if no graph
@@ -228,11 +228,11 @@ public interface GraphProvider {
      * <li>{@link Element}</li>
      * <li>{@link DefaultGraphTraversal}</li>
      * <li>{@link Graph}</li>
-     * <li>{@link Graph.Variables}</li>
+     * <li>{@link org.apache.tinkerpop.gremlin.structure.Graph.Variables}</li>
      * <li>{@link GraphTraversal}</li>
-     * <li>{@link org.apache.tinkerpop.gremlin.process.traversal.traverser.B_O_P_PA_S_SE_SL_Traverser}</li>
+     * <li>{@link B_O_P_PA_S_SE_SL_Traverser}</li>
      * <li>{@link Property}</li>
-     * <li>{@link org.apache.tinkerpop.gremlin.process.traversal.traverser.B_O_PA_S_SE_SL_Traverser}</li>
+     * <li>{@link B_O_PA_S_SE_SL_Traverser}</li>
      * <li>{@link Traversal}</li>
      * <li>{@link Traverser}</li>
      * <li>{@link Vertex}</li>
@@ -245,7 +245,7 @@ public interface GraphProvider {
      * <li>{@link Edge}</li>
      * <li>{@link Element}</li>
      * <li>{@link Graph}</li>
-     * <li>{@link Graph.Variables}</li>
+     * <li>{@link org.apache.tinkerpop.gremlin.structure.Graph.Variables}</li>
      * <li>{@link Property}</li>
      * <li>{@link Vertex}</li>
      * <li>{@link VertexProperty}</li>

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/287553ec/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/process/ProcessComputerSuite.java
----------------------------------------------------------------------
diff --git a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/process/ProcessComputerSuite.java b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/process/ProcessComputerSuite.java
index ebf3a7f..84556e2 100644
--- a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/process/ProcessComputerSuite.java
+++ b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/process/ProcessComputerSuite.java
@@ -83,7 +83,7 @@ import java.util.stream.Stream;
  * {@link Graph} implementation.  This test suite covers traversal operations around {@link GraphComputer} and should
  * be implemented by vendors to validate that their implementations are compliant with that Gremlin language.
  * Implementations that use this test suite should return {@code true} for
- * {@link Graph.Features.GraphFeatures#supportsComputer()}.
+ * {@link org.apache.tinkerpop.gremlin.structure.Graph.Features.GraphFeatures#supportsComputer()}.
  * <br/>
  * For more information on the usage of this suite, please see {@link StructureStandardSuite}.
  *

http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/287553ec/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/structure/StructureStandardSuite.java
----------------------------------------------------------------------
diff --git a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/structure/StructureStandardSuite.java b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/structure/StructureStandardSuite.java
index b5e73bb..0bd86d0 100644
--- a/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/structure/StructureStandardSuite.java
+++ b/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/structure/StructureStandardSuite.java
@@ -51,16 +51,18 @@ import java.util.stream.Stream;
  * "Suite" implements {@link GraphProvider} as a convenience only. It could be implemented in a
  * separate class file):
  * <code>
- * @RunWith(StructureStandardSuite.class)
- * @StructureStandardSuite.GraphProviderClass(TinkerGraphStructureStandardTest.class)
+ * &#064;RunWith(StructureStandardSuite.class)
+ * &#064;StructureStandardSuite.GraphProviderClass(TinkerGraphStructureStandardTest.class)
  * public class TinkerGraphStructureStandardTest implements GraphProvider {
  * }
  * </code>
  * Implementing {@link GraphProvider} provides a way for the {@code StructureStandardSuite} to instantiate
  * {@link Graph} instances from the implementation being tested to inject into tests in the suite.  The
- * {@code StructureStandardSuite} will utilized Features defined in the suite to determine which tests will be executed.
+ * {@code StructureStandardSuite} will utilized Features defined in the suite to determine which tests will be
+ * executed. Note that while the above example demonstrates configuration of this suite, this approach generally
+ * applies to all other test suites.
  * <br/>
- * Set the {@code gremlin.tests} environment variable to a comma separated list of test classes to execute.
+ * Set the {@code GREMLIN_TESTS} environment variable to a comma separated list of test classes to execute.
  * This setting can be helpful to restrict execution of tests to specific ones being focused on during development.
 
  * @author Stephen Mallette (http://stephen.genoprime.com)


[6/6] incubator-tinkerpop git commit: Merge remote-tracking branch 'origin/master' into refactor-io

Posted by sp...@apache.org.
Merge remote-tracking branch 'origin/master' into refactor-io


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/42f367a3
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/42f367a3
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/42f367a3

Branch: refs/heads/refactor-io
Commit: 42f367a367f8c41eb4669b4814137bec9ffca37d
Parents: 4a7a2a5 9990579
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Fri Apr 17 08:53:58 2015 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Fri Apr 17 08:53:58 2015 -0400

----------------------------------------------------------------------
 .../gremlin/process/traversal/Path.java         |  9 +--
 .../process/traversal/TraversalStrategies.java  |  4 --
 .../gremlin/process/traversal/Traverser.java    | 12 ++--
 .../gremlin/process/traversal/util/Metrics.java | 10 ---
 .../gremlin/structure/io/gryo/GryoWriter.java   |  8 ---
 .../structure/util/batch/BatchGraph.java        | 21 +++----
 .../driver/message/ResponseStatusCode.java      |  6 +-
 .../tinkerpop/gremlin/AbstractGremlinSuite.java | 19 +++---
 .../apache/tinkerpop/gremlin/GraphProvider.java | 64 ++++++++++----------
 .../gremlin/process/ProcessComputerSuite.java   |  2 +-
 .../structure/StructureStandardSuite.java       | 10 +--
 .../tinkergraph/structure/TinkerGraph.java      | 36 +++++------
 12 files changed, 90 insertions(+), 111 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/42f367a3/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/GryoWriter.java
----------------------------------------------------------------------


[2/6] incubator-tinkerpop git commit: Fix javadoc warnings in gremlin-driver.

Posted by sp...@apache.org.
Fix javadoc warnings in gremlin-driver.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/cd6d0a85
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/cd6d0a85
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/cd6d0a85

Branch: refs/heads/refactor-io
Commit: cd6d0a854f26ea8ecb7d2c98b9f25d37dff0975e
Parents: ddc29f1
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Fri Apr 17 07:07:47 2015 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Fri Apr 17 07:07:47 2015 -0400

----------------------------------------------------------------------
 .../tinkerpop/gremlin/driver/message/ResponseStatusCode.java   | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/cd6d0a85/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/message/ResponseStatusCode.java
----------------------------------------------------------------------
diff --git a/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/message/ResponseStatusCode.java b/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/message/ResponseStatusCode.java
index 67594e7..c25d784 100644
--- a/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/message/ResponseStatusCode.java
+++ b/gremlin-driver/src/main/java/org/apache/tinkerpop/gremlin/driver/message/ResponseStatusCode.java
@@ -18,6 +18,8 @@
  */
 package org.apache.tinkerpop.gremlin.driver.message;
 
+import org.apache.tinkerpop.gremlin.process.traversal.Traversal;
+
 import java.util.HashMap;
 import java.util.Map;
 import java.util.stream.Stream;
@@ -59,8 +61,8 @@ public enum ResponseStatusCode {
     SERVER_ERROR(500),
 
     /**
-     * The remote {@link org.apache.tinkerpop.gremlin.process.traversal.Traversal} submitted for processing evaluated in on the
-     * server with errors and could not be processed.
+     * The remote {@link Traversal} submitted for processing evaluated in on the server with errors and could not be
+     * processed.
      */
     SERVER_ERROR_TRAVERSAL_EVALUATION(596),
 


[5/6] incubator-tinkerpop git commit: Remove some dead code from GryoWriter.

Posted by sp...@apache.org.
Remove some dead code from GryoWriter.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/99905793
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/99905793
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/99905793

Branch: refs/heads/refactor-io
Commit: 99905793d6db9314c6244cd12aa224f7d81bd79d
Parents: c6c8985
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Fri Apr 17 08:53:21 2015 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Fri Apr 17 08:53:21 2015 -0400

----------------------------------------------------------------------
 .../tinkerpop/gremlin/structure/io/gryo/GryoWriter.java      | 8 --------
 1 file changed, 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/99905793/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/GryoWriter.java
----------------------------------------------------------------------
diff --git a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/GryoWriter.java b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/GryoWriter.java
index 642e7d8..eb60491 100644
--- a/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/GryoWriter.java
+++ b/gremlin-core/src/main/java/org/apache/tinkerpop/gremlin/structure/io/gryo/GryoWriter.java
@@ -45,14 +45,6 @@ import java.util.UUID;
 public class GryoWriter implements GraphWriter {
     private Kryo kryo;
     private final GryoMapper.HeaderWriter headerWriter;
-    private static final UUID delimiter = UUID.fromString("2DEE3ABF-9963-4546-A578-C1C48690D7F7");
-    public static final byte[] DELIMITER = new byte[16];
-
-    static {
-        final ByteBuffer bb = ByteBuffer.wrap(DELIMITER);
-        bb.putLong(delimiter.getMostSignificantBits());
-        bb.putLong(delimiter.getLeastSignificantBits());
-    }
 
     private GryoWriter(final GryoMapper gryoMapper) {
         this.kryo = gryoMapper.createMapper();
diff --git a/tinkergraph-gremlin/src/main/java/org/apache/tinkerpop/gremlin/tinkergraph/structure/TinkerGraph.java b/tinkergraph-gremlin/src/main/java/org/apache/tinkerpop/gremlin/tinkergraph/structure/TinkerGraph.java
index 5eb317d..bcaefed 100644
--- a/tinkergraph-gremlin/src/main/java/org/apache/tinkerpop/gremlin/tinkergraph/structure/TinkerGraph.java
+++ b/tinkergraph-gremlin/src/main/java/org/apache/tinkerpop/gremlin/tinkergraph/structure/TinkerGraph.java
@@ -29,6 +29,7 @@ import org.apache.tinkerpop.gremlin.structure.Transaction;
 import org.apache.tinkerpop.gremlin.structure.Vertex;
 import org.apache.tinkerpop.gremlin.structure.VertexProperty;
 import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
+import org.apache.tinkerpop.gremlin.structure.util.GraphFactory;
 import org.apache.tinkerpop.gremlin.structure.util.StringFactory;
 import org.apache.tinkerpop.gremlin.tinkergraph.process.computer.TinkerGraphComputer;
 import org.apache.tinkerpop.gremlin.tinkergraph.process.computer.TinkerGraphView;
@@ -108,10 +109,10 @@ public class TinkerGraph implements Graph {
 
     /**
      * Open a new {@link TinkerGraph} instance.
-     * <p/>
-     * <b>Reference Implementation Help:</b> If a {@link org.apache.tinkerpop.gremlin.structure.Graph } implementation does not require a
-     * {@link org.apache.commons.configuration.Configuration} (or perhaps has a default configuration) it can choose to implement a zero argument
-     * open() method. This is an optional constructor method for TinkerGraph. It is not enforced by the Gremlin
+     * <br/>
+     * <b>Reference Implementation Help:</b> If a {@link Graph} implementation does not require a {@code Configuration}
+     * (or perhaps has a default configuration) it can choose to implement a zero argument
+     * {@code open()} method. This is an optional constructor method for TinkerGraph. It is not enforced by the Gremlin
      * Test Suite.
      */
     public static TinkerGraph open() {
@@ -119,19 +120,17 @@ public class TinkerGraph implements Graph {
     }
 
     /**
-     * Open a new {@link TinkerGraph} instance.
-     * <p/>
-     * <b>Reference Implementation Help:</b> This method is the one use by the
-     * {@link org.apache.tinkerpop.gremlin.structure.util.GraphFactory} to instantiate
-     * {@link org.apache.tinkerpop.gremlin.structure.Graph} instances.  This method must be overridden for the Structure Test
-     * Suite to pass. Implementers have latitude in terms of how exceptions are handled within this method.  Such
-     * exceptions will be considered implementation specific by the test suite as all test generate graph instances
-     * by way of {@link org.apache.tinkerpop.gremlin.structure.util.GraphFactory}. As such, the exceptions get generalized
-     * behind that facade and since {@link org.apache.tinkerpop.gremlin.structure.util.GraphFactory} is the preferred method
-     * to opening graphs it will be consistent at that level.
+     * Open a new {@code TinkerGraph} instance.
+     * <br/>
+     * <b>Reference Implementation Help:</b> This method is the one use by the {@link GraphFactory} to instantiate
+     * {@link Graph} instances.  This method must be overridden for the Structure Test Suite to pass. Implementers have
+     * latitude in terms of how exceptions are handled within this method.  Such exceptions will be considered
+     * implementation specific by the test suite as all test generate graph instances by way of
+     * {@link GraphFactory}. As such, the exceptions get generalized behind that facade and since
+     * {@link GraphFactory} is the preferred method to opening graphs it will be consistent at that level.
      *
      * @param configuration the configuration for the instance
-     * @return a newly opened {@link org.apache.tinkerpop.gremlin.structure.Graph}
+     * @return a newly opened {@link Graph}
      */
     public static TinkerGraph open(final Configuration configuration) {
         return new TinkerGraph(configuration);
@@ -254,9 +253,10 @@ public class TinkerGraph implements Graph {
 
     /**
      * Return TinkerGraph feature set.
-     * <p/>
+     * <br/>
      * <b>Reference Implementation Help:</b> Implementers only need to implement features for which there are
      * negative or instance configured features.  By default, all {@link Features} return true.
      */
     @Override
     public Features features() {
@@ -396,7 +396,7 @@ public class TinkerGraph implements Graph {
     }
 
     /**
-     * Construct an {@link TinkerGraph.IdManager} from the TinkerGraph {@link Configuration}.
+     * Construct an {@link TinkerGraph.IdManager} from the TinkerGraph {@code Configuration}.
      */
     private static IdManager<?> selectIdManager(final Configuration config, final String configKey, final Class<? extends Element> clazz) {
         final String vertexIdManagerConfigValue = config.getString(configKey, DefaultIdManager.ANY.name());


[3/6] incubator-tinkerpop git commit: Fix javadoc warnings in gremlin-test.

Posted by sp...@apache.org.
Fix javadoc warnings in gremlin-test.


Project: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/commit/287553ec
Tree: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/tree/287553ec
Diff: http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/diff/287553ec

Branch: refs/heads/refactor-io
Commit: 287553ec5907a40225479ae9805bde9ccd0bb6d0
Parents: cd6d0a8
Author: Stephen Mallette <sp...@genoprime.com>
Authored: Fri Apr 17 07:30:01 2015 -0400
Committer: Stephen Mallette <sp...@genoprime.com>
Committed: Fri Apr 17 07:30:01 2015 -0400

----------------------------------------------------------------------
 .../tinkerpop/gremlin/AbstractGremlinSuite.java | 19 +++---
 .../apache/tinkerpop/gremlin/GraphProvider.java | 64 ++++++++++----------
 .../gremlin/process/ProcessComputerSuite.java   |  2 +-
 .../structure/StructureStandardSuite.java       | 10 +--
 4 files changed, 50 insertions(+), 45 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-tinkerpop/blob/287553ec/gremlin-test/src/main/java/org/apache/tinkerpop/gremlin/AbstractGremlinSuite.java
----------------------------------------------------------------------
@@ -254,9 +253,10 @@ public class TinkerGraph implements Graph {
      * <b>Reference Implementation Help:</b> Implementers only need to implement features for which there are
-     * negative or instance configured features.  By default, all {@link Features} return true.
+     * negative or instance configured features.  By default, all
+     * {@link org.apache.tinkerpop.gremlin.structure.Graph.Features} return true.
      */
     @Override